%bcond_without	qt5
%bcond_without	qt6

Name:		quazip
Version:	1.5
Release:	%mkrel 1
Summary:	Qt/C++ wrapper for the minizip library
License:	LGPLv2+
Group:		Development/C++
URL:		https://github.com/stachenov/quazip
Source0:	https://github.com/stachenov/quazip/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	graphviz
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(libzip)
### Qt5 build dependencies
%if %{with qt5}
BuildRequires:	cmake(Qt5Core)
BuildRequires:	cmake(Qt5Gui)
BuildRequires:	cmake(Qt5Network)
BuildRequires:	cmake(Qt5Test)
BuildRequires:	cmake(Qt5Widgets)
%endif
### Qt6 build dependencies
%if %{with qt6}
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Core5Compat)
BuildRequires:	cmake(Qt6Gui)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6Test)
BuildRequires:	cmake(Qt6Widgets)
%endif

%description
QuaZIP is a simple C++ wrapper over Gilles Vollant's ZIP/UNZIP package that
can be used to access ZIP archives. It uses Trolltech's Qt toolkit.

QuaZIP allows you to access files inside ZIP archives using QIODevice API,
and - yes! - that means that you can also use QTextStream, QDataStream or
whatever you would like to use on your zipped files.

QuaZIP provides complete abstraction of the ZIP/UNZIP API, for both reading
from and writing to ZIP archives.

#------------------------------------------------------------------------------
### Qt5 ###

%if %{with qt5}

%define api		1
%define quazip_major	1.5.0
%define libquazip_qt5	%mklibname %{name}%{api}-qt5_ %{quazip_major}

%package -n	%{libquazip_qt5}
Summary:	Minizip wrapper library for Qt 5.x
Group:		System/Libraries

%description -n	%{libquazip_qt5}
QuaZIP is a simple C++ wrapper over Gilles Vollant's ZIP/UNZIP package that
can be used to access ZIP archives.

This package provides the Qt5 runtime library for %{name}.

%files -n %{libquazip_qt5}
%doc NEWS.txt QuaZip-1.x-migration.md
%license COPYING
%{_libdir}/lib%{name}%{api}-qt5.so.%{quazip_major}{,.*}
%{_libdir}/lib%{name}%{api}-qt5.so.%{version}

#------------------------------------------------------------------------------

%define develquazip_qt5	%mklibname %{name}%{api}-qt5 -d

%package -n	%{develquazip_qt5}
Summary:	Development files for %{name}
Group:		Development/KDE and Qt
Requires:	%{libquazip_qt5} = %{version}-%{release}
Requires:	pkgconfig(libzip)
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{name}-qt5-devel = %{version}-%{release}
Provides:	%{name}%{api}-qt5-devel = %{version}-%{release}

%description -n	%{develquazip_qt5}
QuaZIP is a simple C++ wrapper over Gilles Vollant's ZIP/UNZIP package that
can be used to access ZIP archives.

This package provides the Qt5 headers files needed to build a package against
%{name}.

%files -n %{develquazip_qt5}
%doc doc/html
%doc CONTRIBUTING.md README.md NEWS.txt QuaZip-1.x-migration.md
%license COPYING
%{_includedir}/QuaZip-Qt5-%{version}/
%{_libdir}/lib%{name}%{api}-qt5.so
%{_libdir}/cmake/QuaZip-Qt5-%{version}/
%{_libdir}/pkgconfig/%{name}%{api}-qt5.pc
%endif

### End Qt5 ###

#------------------------------------------------------------------------------
### Qt6 ###

%if %{with qt6}

%define api		1
%define quazip_major	1.5.0
%define libquazip_qt6	%mklibname %{name}%{api}-qt6_ %{quazip_major}

%package -n	%{libquazip_qt6}
Summary:	Minizip wrapper library for Qt 6.x
Group:		System/Libraries

%description -n	%{libquazip_qt6}
QuaZIP is a simple C++ wrapper over Gilles Vollant's ZIP/UNZIP package that
can be used to access ZIP archives.

This package provides the Qt6 runtime library for %{name}.

%files -n %{libquazip_qt6}
%doc NEWS.txt QuaZip-1.x-migration.md
%license COPYING
%{_libdir}/lib%{name}%{api}-qt6.so.%{quazip_major}{,.*}
%{_libdir}/lib%{name}%{api}-qt6.so.%{version}

#------------------------------------------------------------------------------

%define develquazip_qt6	%mklibname %{name}%{api}-qt6 -d

%package -n	%{develquazip_qt6}
Summary:	Development files for %{name}-qt6
Group:		Development/KDE and Qt
Requires:	%{libquazip_qt6} = %{version}-%{release}
Requires:	pkgconfig(libzip)
Provides:	lib%{name}-qt6-devel = %{version}-%{release}
Provides:	%{name}-qt6-devel = %{version}-%{release}
Provides:	%{name}%{api}-qt6-devel = %{version}-%{release}

%description -n	%{develquazip_qt6}
QuaZIP is a simple C++ wrapper over Gilles Vollant's ZIP/UNZIP package that
can be used to access ZIP archives.

This package provides the Qt6 headers files needed to build a package against
%{name}.

%files -n %{develquazip_qt6}
%doc doc/html
%doc CONTRIBUTING.md README.md NEWS.txt QuaZip-1.x-migration.md
%license COPYING
%{_includedir}/QuaZip-Qt6-%{version}/
%{_libdir}/lib%{name}%{api}-qt6.so
%{_libdir}/cmake/QuaZip-Qt6-%{version}/
%{_libdir}/pkgconfig/%{name}%{api}-qt6.pc
%endif

### End Qt6 ###

#------------------------------------------------------------------------------

%prep
%autosetup -p1

%build
### Build Qt5 ###
%if %{with qt5}
%define _vpath_builddir build-qt5
%cmake_qt5 -DQUAZIP_QT_MAJOR_VERSION=5
%cmake_build
%endif

### Build Qt6 ###
%if %{with qt6}
%define _vpath_builddir build-qt6
%cmake_qt6 -DQUAZIP_QT_MAJOR_VERSION=6
%cmake_build
%endif

### Build doc ###
doxygen Doxyfile
for file in doc/html/*; do
       touch -r Doxyfile $file
done

%install
%if %{with qt5}
%define _vpath_builddir build-qt5
%cmake_install
%endif

%if %{with qt6}
%define _vpath_builddir build-qt6
%cmake_install
%endif


%changelog
* Sat Jun 14 2025 daviddavid <daviddavid> 1.5-1.mga10
+ Revision: 2191267
- new version: 1.5

* Sat Sep 02 2023 daviddavid <daviddavid> 1.4-1.mga10
+ Revision: 1983520
- new version: 1.4

* Wed Jan 04 2023 daviddavid <daviddavid> 1.3-2.mga9
+ Revision: 1929808
- enable Qt6 support

* Sat Sep 10 2022 neoclust <neoclust> 1.3-1.mga9
+ Revision: 1886352
- New version 1.3

* Sun Apr 03 2022 umeabot <umeabot> 1.1-2.mga9
+ Revision: 1842444
- Mageia 9 Mass Rebuild

* Tue May 18 2021 daviddavid <daviddavid> 1.1-1.mga9
+ Revision: 1725472
- new version: 1.1
- now libmajor is 1.0.0
- QuaZip 1.0 introduced some important changes:
  * modern CMake support was introduced
  * include paths and binary names were changed
  * qmake support was ditched completely

* Thu Dec 17 2020 umeabot <umeabot> 0.9.1-2.mga8
+ Revision: 1659712
- Rebuild for new Qt5

* Mon Aug 31 2020 daviddavid <daviddavid> 0.9.1-1.mga8
+ Revision: 1620248
- new version: 0.9.1

* Sun Feb 16 2020 daviddavid <daviddavid> 0.8.1-3.mga8
+ Revision: 1533415
- add virtual provides on quazip-qt5-devel
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Thu Sep 19 2019 daviddavid <daviddavid> 0.8.1-2.mga8
+ Revision: 1443834
- time to drop Qt4 support

* Tue Sep 03 2019 daviddavid <daviddavid> 0.8.1-1.mga8
+ Revision: 1436526
- new version: 0.8.1

* Mon Apr 01 2019 umeabot <umeabot> 0.7.6-3.mga7
+ Revision: 1384614
- Qt5 Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 0.7.6-2.mga7
+ Revision: 1300749
- Mageia 7 Mass Rebuild

* Fri Jun 22 2018 daviddavid <daviddavid> 0.7.6-1.mga7
+ Revision: 1238723
- new version: 0.7.6, fixes CVE-2018-1002209 (mga#23446)
- update URL and Source URL
- rename and rediff fix_static patch

* Tue Jul 25 2017 daviddavid <daviddavid> 0.7.3-1.mga7
+ Revision: 1130797
- new version: 0.7.3

* Tue May 10 2016 daviddavid <daviddavid> 0.7.2-2.mga6
+ Revision: 1011975
- provides also a quazip Qt4 build (still needed for tomahawk-player)

* Mon May 09 2016 luigiwalser <luigiwalser> 0.7.2-1.mga6
+ Revision: 1011646
- fix library package name and corresponding file names
- 0.7.2
- remove upstreamed patch
- add patch from fedora to fix build

* Tue Feb 16 2016 umeabot <umeabot> 0.7.1-2.mga6
+ Revision: 962694
- Mageia 6 Mass Rebuild

* Fri Jul 03 2015 anaselli <anaselli> 0.7.1-1.mga6
+ Revision: 849795
- new 0.7.1
- New version

* Wed Oct 15 2014 umeabot <umeabot> 0.7-3.mga5
+ Revision: 748555
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.7-2.mga5
+ Revision: 688578
- Mageia 5 Mass Rebuild

* Sun Aug 10 2014 anaselli <anaselli> 0.7-1.mga5
+ Revision: 661373
- new version 7.0

* Sat Oct 19 2013 umeabot <umeabot> 0.5.1-2.mga4
+ Revision: 529046
- Mageia 4 Mass Rebuild

* Tue Jul 02 2013 dams <dams> 0.5.1-1.mga4
+ Revision: 449523
- new version 0.5.1

* Sun Jan 13 2013 umeabot <umeabot> 0.5-2.mga3
+ Revision: 380106
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Sep 11 2012 anaselli <anaselli> 0.5-1.mga3
+ Revision: 292461
- new 0.5 version

* Tue Aug 07 2012 neoclust <neoclust> 0.4.4-2.mga3
+ Revision: 279766
- Make sure to not build against Qt5

* Sun Mar 25 2012 anaselli <anaselli> 0.4.4-1.mga2
+ Revision: 226430
- Upstream bug fixing release

* Wed Dec 21 2011 anaselli <anaselli> 0.4.3-3.mga2
+ Revision: 185573
- Fixed provides info for developer package

* Fri Dec 16 2011 mikala <mikala> 0.4.3-2.mga2
+ Revision: 182664
- Add missing obsoletes

* Fri Dec 16 2011 mikala <mikala> 0.4.3-1.mga2
+ Revision: 182659
- Use pkgconfig for BR
- Fix Group
- Fix subpackages (use proper libification)
+ anaselli <anaselli>
- new version 0.4.3
- imported package quazip

